import os
import webbrowser

class JarvisFileOpener:
    def __init__(self):
        self._file = ""

    @property
    def open(self):
        return self._file

    @open.setter
    def open(self, path_or_url):
        self._file = path_or_url
        if path_or_url.lower().startswith(("http://", "https://")):
            try:
                webbrowser.open(path_or_url)
            except:
                pass
        elif os.path.exists(path_or_url):
            try:
                os.startfile(path_or_url)
            except:
                pass

jarvisfileopen = JarvisFileOpener()



from setuptools import setup, find_packages

setup(
    name="jarvisfileopen",
    version="1.0.0",
    description="Libreria per aprire file in stile Jarvis con un semplice comando: open",
    long_description=open("README.md", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    author="Mattia Leoni",
    author_email="mattia.leoni15@icloud.com",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: Microsoft :: Windows",
    ],
    python_requires=">=3.6"
)
